pub enum ConnectStatus {
Connected,
InProgress,
}Expand description
Progress of a connection attempt whose completion is readiness-driven.
Variants
Connected
The transport completed the connection synchronously or asynchronously.
InProgress
The transport started an asynchronous connection and is not ready yet.