pub enum SocketAddrEx {
Ip(SocketAddr),
Unix(UnixSocketAddr),
}Expand description
Extended socket address supporting IP, Unix, and vsock address families.
Variants
Implementations
Sourceimpl SocketAddrEx
impl SocketAddrEx
Sourcepub fn into_ip(self) -> NetResult<SocketAddr>
pub fn into_ip(self) -> NetResult<SocketAddr>
Convert into an IP socket address, or return an error if not IP.
Sourcepub fn into_unix(self) -> NetResult<UnixSocketAddr>
pub fn into_unix(self) -> NetResult<UnixSocketAddr>
Convert into a Unix socket address, or return an error if not Unix.