pub enum TxQueueDiscipline {
NoQueue,
Fifo {
max_frames: NonZeroUsize,
},
}Expand description
Protocol-side transmit queue policy for one network device.
Variants
NoQueue
Submit directly to the device and return Again when it is busy.
Fifo
Retain frames in submission order while the device is busy.
Fields

max_frames: NonZeroUsizeTrait Implementations
Sourceimpl Clone for TxQueueDiscipline
impl Clone for TxQueueDiscipline
Sourcefn clone(&self) -> TxQueueDiscipline
fn clone(&self) -> TxQueueDiscipline
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TxQueueDiscipline
Sourceimpl Debug for TxQueueDiscipline
impl Debug for TxQueueDiscipline
impl Eq for TxQueueDiscipline
Sourceimpl PartialEq for TxQueueDiscipline
impl PartialEq for TxQueueDiscipline
impl StructuralPartialEq for TxQueueDiscipline