pub struct InterfaceConfig {
pub name: String,
pub match_by: InterfaceMatcher,
pub static_ip: Option<StaticIpConfig>,
pub dhcp: bool,
pub metric: u32,
pub dns_servers: Vec<Ipv4Addr>,
}Expand description
Per-interface network configuration.
Fields
name: StringPublic interface name, for example eth0.
match_by: InterfaceMatcherRule used to bind this config to one probed device.
static_ip: Option<StaticIpConfig>Static IPv4 configuration. Mutually exclusive with DHCP.
dhcp: boolWhether DHCP client configuration is enabled.
metric: u32Route metric used for routes installed from this interface.
dns_servers: Vec<Ipv4Addr>Static DNS servers associated with this interface.