pub struct SocketWaitPolicy {
pub nonblocking: bool,
pub timeout: Option<Duration>,
}Expand description
OS-facing policy for driving one task-neutral socket future.
Fields
nonblocking: boolWhether this operation must return after the registration recheck.
timeout: Option<Duration>Optional relative timeout owned and enforced by the consuming OS.