pub struct UnixCredentials {
pub pid: u32,
pub uid: u32,
pub gid: u32,
/* private fields */
}Expand description
Transport-owned Unix credentials plus an optional OS identity generation.
pid, uid, and gid are ABI-compatible fallback values. OS layers with
PID namespaces can attach their generation object opaquely so queued
messages and peer sockets do not depend on a reusable numeric PID.
Fields
pid: u32Process ID.
uid: u32User ID.
gid: u32Group ID.
Implementations
Sourceimpl UnixCredentials
impl UnixCredentials
Sourcepub fn new(pid: u32) -> Self
pub fn new(pid: u32) -> Self
Create a new UnixCredentials with the given PID and default UID/GID.
Sourcepub fn from_parts(pid: u32, uid: u32, gid: u32) -> Self
pub fn from_parts(pid: u32, uid: u32, gid: u32) -> Self
Creates credentials with explicit numeric fallback values.
Sourcepub fn with_identity<T>(self, identity: Arc<T>) -> Self
pub fn with_identity<T>(self, identity: Arc<T>) -> Self
Attaches an OS-specific stable process generation.